PRISMA_default_or_csv_: Pull from CSV, or use a default value if not in the CSV

PRISMA_default_or_csv_R Documentation

Pull from CSV, or use a default value if not in the CSV

Description

set the variable from the CSV, or a default value

Usage

PRISMA_default_or_csv_(expr, default, var_name = "not provided")

Arguments

expr

the expression to get the variable from the CSV

default

the default token

var_name

the variable name

Value

the result of 'expr', or 'default'


PRISMA2020 documentation built on July 1, 2026, 9:06 a.m.